@@ -31,5 +31,5 @@ async def _main(args):
     await load_msgdefs(ebus, args)
     msgdefs = ebus.msgdefs.resolve(args.patterns.split(";"))
     print(f"Observing {msgdefs.summary()}")
-    async for msg in ebus.observe(msgdefs=msgdefs, prio=args.prio, ttl=args.ttl):
+    async for msg in ebus.observe(msgdefs=msgdefs, defaultprio=9, setprio=args.prio, ttl=args.ttl):
         print_msg(msg)
